@@ -1,14 +1,17 @@
+// Copyright (c) 2023 Yuki Kimoto
+// MIT License
+
 #ifndef SPVM_USE_H
 #define SPVM_USE_H
 
 #include "spvm_typedecl.h"
 
 struct spvm_use {
-  SPVM_OP* op_type;
-  SPVM_LIST* sub_names;
-  int32_t is_require;
-  int32_t load_fail;
+  SPVM_OP* op_use;
+  const char* class_name;
+  const char* class_alias_name;
   const char* file;
+  int8_t is_require;
 };
 
 SPVM_USE* SPVM_USE_new(SPVM_COMPILER* compiler);
