@@ -102,7 +102,7 @@ Native APIs have its IDs. These IDs are permanently same for the binary compatib
    85 set_class_var_object
    86 get_pointer
    87 set_pointer
-   88 call_method
+   88 call_method_raw
    89 get_exception
    90 set_exception
    91 get_ref_count
@@ -219,7 +219,11 @@ Native APIs have its IDs. These IDs are permanently same for the binary compatib
   202 get_compile_type_name_raw
   203 get_compile_type_name
   204 set_command_info_base_time
-  205 get_spvm_version
+  205 get_spvm_version_string
+  206 get_spvm_version_number
+  207 get_version_string
+  208 get_version_number
+  209 call_method
 
 =head2 class_vars_heap
 
@@ -378,7 +382,7 @@ Examples:
 
 Gets a class method ID by the class name, the method name. If the class method does not exists, a negative value is returned.
 
-This ID is used by L<"call_method">.
+This ID is used by L<"call_method_raw">.
 
 Examples:
 
@@ -390,7 +394,7 @@ Examples:
 
 Gets a instance method ID by the object, the method name. If the instance method does not exist, a negative value is returned.
 
-This ID is used by L<"call_method">.
+This ID is used by L<"call_method_raw">.
 
 Examples:
 
@@ -1053,13 +1057,13 @@ Examples:
 
 If you specify a pointer object and a C language pointer, the C language pointer is saved in the internal data of the pointer type object.
 
-=head2 call_method
+=head2 call_method_raw
 
-  int32_t (*call_method)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t method_id, int32_t args_stack_length);
+  int32_t (*call_method_raw)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t method_id, int32_t args_stack_length);
 
 Call a method by specifying the method ID and the stack length of the argument. If an exception occurs in the method, The return value is 1. If not, return 0.
 
-The return value of the method is set to args[0].
+The return value of the method is set to stack[0].
 
 =head2 get_exception
 
@@ -1739,7 +1743,7 @@ Examples:
     const char* class_name, const char* method_name, int32_t args_stack_length,
     const char* func_name, const char* file, int32_t line);
 
-This is same as C<call_method> function, but you can specify the class name and method name directly.
+This is same as C<call_method_raw> function, but you can specify the class name and method name directly.
 
 Examples:
 
@@ -1792,7 +1796,7 @@ The same as C<dump_raw>, and push the created object to the mortal stack. Use th
 
 Gets a instance method ID by the class name, the method name. If the instance method does not exists, a negative value is returned.
 
-This ID is used by L<"call_method">.
+This ID is used by L<"call_method_raw">.
 
 Examples:
 
@@ -2181,7 +2185,7 @@ Examples:
 
 Gets a method ID by the class name and the method name. If the method does not exists, a negative value is returned.
 
-This ID is used by L<"call_method">.
+This ID is used by L<"call_method_raw">.
 
 Examples:
 
@@ -2223,11 +2227,43 @@ If it succeed, return 0.
 
 The program name must be a C<string> object. Otherwise return non-zero value.
 
-=head2 get_spvm_version
+=head2 get_spvm_version_string
 
-  const char* (*get_spvm_version)(SPVM_ENV* env, SPVM_VALUE* stack);
+  const char* (*get_spvm_version_string)(SPVM_ENV* env, SPVM_VALUE* stack);
 
-Returns the version of the SPVM language.
+Returns the L<version string|SPVM::Document::Language/"Version String"> of the SPVM language.
+
+=head2 get_spvm_version_number
+
+  double (*get_spvm_version_number)(SPVM_ENV* env, SPVM_VALUE* stack);
+
+Returns the L<version number|SPVM::Document::Language/"Version Number"> of the SPVM language.
+
+=head2 get_version_string
+
+  const char* (*get_version_string)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t class_id);
+
+Returns the version string of a class. The C<class_id> must be a valid class id.
+
+If the version string in the class is not defined, returns NULL.
+
+=head2 get_version_number
+
+  double (*get_version_number)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t class_id);
+
+Returns the version number of a class. The C<class_id> must be a valid class id.
+
+If the version string in the class is not defined, returns -1.
+
+=head2 call_method
+
+  int32_t (*call_method)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t method_id, int32_t args_stack_length);
+
+Call a method by specifying the method ID and the stack length of the argument. If an exception occurs in the method, The return value is 1. If not, return 0.
+
+The return value of the method is set to stack[0].
+
+If stack[0] is a value of an object type, the object is pushed to the mortal stack.
 
 =head1 Compiler Native API
 
